@@ -610,6 +610,22 @@ class BatchHandler(object):
         invoked whenever rows are added, removed, updated etc.
         """
 
+    def write_worksheet(self, batch, progress=None):
+        """
+        Write a worksheet file, to be downloaded by the user.  Must return the
+        file path.
+        """
+        raise NotImplementedError("Please define logic for `{}.write_worksheet()`".format(
+            self.__class__.__name__))
+
+    def update_from_worksheet(self, batch, path, progress=None):
+        """
+        Save the given file to a batch-specific location, then update the
+        batch data from the file contents.
+        """
+        raise NotImplementedError("Please define logic for `{}.update_from_worksheet()`".format(
+            self.__class__.__name__))
+
     def mark_complete(self, batch, progress=None):
         """
         Mark the given batch as "complete".  This usually is just a matter of
