@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -1005,7 +1005,7 @@ class MakeAppDir(Subcommand):
 
         if args.user:
             pwdata = pwd.getpwnam(args.user)
-        for name in ['batch', 'log', 'sessions', 'work']:
+        for name in ['batch', 'data', 'log', 'sessions', 'work']:
             path = os.path.join(app_path, name)
             if not os.path.exists(path):
                 os.mkdir(path)
@@ -1073,7 +1073,10 @@ class MakeUser(Subcommand):
                             help="Whether the new user should have admin rights within "
                             "the system (if applicable).")
         parser.add_argument('--password',
-                            help="Optional password to set for the new user.")
+                            help="Password to set for the new user.  If not specified, "
+                            "you may be prompted for one.")
+        parser.add_argument('--no-password', action='store_true',
+                            help="Do not ask for, or try to set, a password for the new user.")
         parser.add_argument('--full-name',
                             help="Full (display) name for the new user (if applicable).")
         parser.add_argument('--comment',
@@ -1134,7 +1137,8 @@ class MakeUser(Subcommand):
                     roles.append(role)
 
         user = model.User(username=args.username)
-        auth.set_user_password(user, self.obtain_password(args))
+        if not args.no_password:
+            auth.set_user_password(user, self.obtain_password(args))
 
         if args.admin:
             user.roles.append(auth.administrator_role(session))
@@ -1161,6 +1165,10 @@ class MakeUser(Subcommand):
         from rattail.win32 import users
         from rattail.win32 import require_elevation
 
+        if args.no_password:
+            self.stderr.write("sorry, a password is required when making a 'win32' user\n")
+            sys.exit(1)
+
         require_elevation()
 
         if users.user_exists(args.username):
