@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -34,6 +34,7 @@ import six
 from rattail.commands.core import Subcommand, date_argument
 from rattail.config import parse_list
 from rattail.util import load_object
+from rattail.core import Object
 
 
 log = logging.getLogger(__name__)
@@ -461,12 +462,10 @@ class ImportVersions(ImportRattail):
         super(ImportVersions, self).run(args)
 
 
-class PurgeVersions(Subcommand):
+class VersionSubcommand(Subcommand):
     """
-    Purge version data for some or all tables
+    Base class for subcommands which act on version data
     """
-    name = 'purge-versions'
-    description = __doc__.strip()
 
     def add_parser_args(self, parser):
 
@@ -477,25 +476,6 @@ class PurgeVersions(Subcommand):
                             help="Go through the full motions and allow logging etc. to "
                             "occur, but rollback (abort) the transaction at the end.")
 
-    def run(self, args):
-        if not self.config.versioning_enabled():
-            self.stderr.write("Continuum versioning is not enabled, per config\n")
-            sys.exit(1)
-
-        if args.list:
-            self.list_models()
-
-        else:
-            session = self.make_session()
-            self.purge_models(session)
-            if args.dry_run:
-                session.rollback()
-                log.info("dry run, so transaction was aborted")
-            else:
-                session.commit()
-                log.info("transaction was committed")
-            session.close()
-
     def collect_models(self):
         """
         Gather and return a dict of data model classes, for which version
@@ -537,6 +517,33 @@ class PurgeVersions(Subcommand):
         else:
             log.warning("hm, no version classes found; is versioning enabled?")
 
+
+class PurgeVersions(VersionSubcommand):
+    """
+    Purge version data for some or all tables
+    """
+    name = 'purge-versions'
+    description = __doc__.strip()
+
+    def run(self, args):
+        if not self.config.versioning_enabled():
+            self.stderr.write("Continuum versioning is not enabled, per config\n")
+            sys.exit(1)
+
+        if args.list:
+            self.list_models()
+
+        else:
+            session = self.make_session()
+            self.purge_models(session)
+            if args.dry_run:
+                session.rollback()
+                log.info("dry run, so transaction was aborted")
+            else:
+                session.commit()
+                log.info("transaction was committed")
+            session.close()
+
     def purge_models(self, session):
         """
         Purge version data for all given models.
@@ -569,3 +576,87 @@ class PurgeVersions(Subcommand):
         log.debug("will now purge data for version table: %s", vtable.name)
         session.execute('truncate "{}"'.format(vtable.name))
         self.stdout.write("purged data for: {}\n".format(vtable.name))
+
+
+class VersionCheck(VersionSubcommand):
+    """
+    Run consistency checks for version data tables
+    """
+    name = 'version-check'
+    description = __doc__.strip()
+
+    def add_parser_args(self, parser):
+        super(VersionCheck, self).add_parser_args(parser)
+
+        parser.add_argument('models', nargs='*', metavar='MODEL',
+                            help="Which data models to check.  If you specify any, then only "
+                            "data for those models will be checked.  If you do not specify "
+                            "any, then all supported models will be checked.")
+
+    def run(self, args):
+        if not self.config.versioning_enabled():
+            self.stderr.write("Continuum versioning is not enabled, per config\n")
+            sys.exit(1)
+
+        if args.list:
+            self.list_models()
+
+        else:
+            session = self.make_session()
+            self.run_version_checks(session, args.models)
+            self.finalize_session(session, dry_run=args.dry_run)
+
+    def run_version_checks(self, session, models):
+        """
+        Run version data checks for all given models.
+        """
+        requested = models
+        all_models = self.collect_models()
+        if requested:
+            models = dict([(k, v)
+                           for k, v in six.iteritems(all_models)
+                           if k in requested])
+        else:
+            models = all_models
+        if not models:
+            log.warning("i have no models to check!")
+            return
+
+        for name, cls in sorted(six.iteritems(models)):
+            self.check_versions(session, cls)
+
+        log.info("checked version data for %s models", len(models))
+
+    def check_versions(self, session, cls):
+        """
+        Check version data for the given model class.
+        """
+        import sqlalchemy_continuum as continuum
+
+        model_name = cls.__name__
+        log.debug("will now check version data for model: %s", model_name)
+
+        vcls = continuum.version_class(cls)
+        versions = session.query(vcls).all()
+        versions_by_uuid = {}
+        result = Object(problems=0)
+
+        def organize(version, i):
+            versions_by_uuid.setdefault(version.uuid, []).append(version)
+
+        self.progress_loop(organize, versions,
+                           message="Organizing version data for {}".format(model_name))
+
+        def check(uuid, i):
+            versions = versions_by_uuid[uuid]
+            created = [v for v in versions
+                       if v.operation_type == continuum.Operation.INSERT]
+            if len(created) != 1:
+                log.warning("should be 1 INSERT for %s %s, but found %s",
+                            model_name, uuid, len(created))
+                result.problems += 1
+
+        self.progress_loop(check, list(versions_by_uuid.keys()),
+                           message="Checking version data for {}".format(model_name))
+
+        log.info("found %s problems for model: %s", result.problems, model_name)
