@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2019 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -26,6 +26,8 @@ DataSync Configuration
 
 from __future__ import unicode_literals, absolute_import
 
+import re
+
 from rattail.config import ConfigProfile, parse_list
 from rattail.util import load_object
 from rattail.exceptions import ConfigurationError
@@ -53,7 +55,18 @@ class DataSyncProfile(ConfigProfile):
             self.watcher = NullWatcher(config, key)
         else:
             dbkey = self._config_string('watcher.db', default='default')
-            self.watcher = load_object(self.watcher_spec)(config, key, dbkey=dbkey)
+            kwargs = {'dbkey': dbkey}
+            pattern = re.compile(r'^{}\.watcher\.kwarg\.(?P<keyword>\w+)$'.format(self.key))
+            # TODO: this should not be referencing the config parser directly?
+            # (but we have no other way yet, to know which options are defined)
+            # (we should at least allow config to be defined in DB Settings)
+            # (however that should be optional, since some may not have a DB)
+            for option in self.config.parser.options(self.section):
+                match = pattern.match(option)
+                if match:
+                    keyword = match.group('keyword')
+                    kwargs[keyword] = self.config.get(self.section, option)
+            self.watcher = load_object(self.watcher_spec)(config, key, **kwargs)
         self.watcher.delay = self._config_int('watcher.delay', default=self.watcher.delay)
         self.watcher.retry_attempts = self._config_int('watcher.retry_attempts', default=self.watcher.retry_attempts)
         self.watcher.retry_delay = self._config_int('watcher.retry_delay', default=self.watcher.retry_delay)
