@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -76,7 +76,7 @@ if sqlalchemy:
             from rattail.db import model
 
             if isinstance(user_info, model.User):
-                user = user_info
+                user = self.merge(user_info)
             else:
                 user = self.query(model.User).get(user_info)
                 if not user:
@@ -87,7 +87,8 @@ if sqlalchemy:
             self.continuum_user = user
 
 
-    Session = orm.sessionmaker(class_=SessionBase, rattail_config=None, rattail_record_changes=False)
+    Session = orm.sessionmaker(class_=SessionBase, rattail_config=None, rattail_record_changes=False, expire_on_commit=False)
+
 
 else: # no sqlalchemy
     Session = None
@@ -125,7 +126,7 @@ class ConfigExtension(BaseExtension):
     key = 'rattail.db'
 
     def configure(self, config):
-        from rattail.db.config import get_engines, configure_session, configure_versioning
+        from rattail.db.config import get_engines, configure_session
 
         if Session:
 
@@ -136,6 +137,3 @@ class ConfigExtension(BaseExtension):
 
             # TODO: This should be removed, it sets 'record changes' globally.
             configure_session(config, Session)
-
-            # TODO: I have no idea if this works, probably not.
-            configure_versioning(config)
