@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# -*- coding: utf-8; -*-
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2019 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,16 @@
 Database API
 """
 
+from __future__ import unicode_literals, absolute_import
+
 from rattail.db.api.people import get_employee_by_id
 from rattail.db.api.products import (
-    get_product_by_upc, get_product_by_code, get_product_by_vendor_code,
+    get_product_by_upc, get_product_by_item_id, get_product_by_scancode,
+    get_product_by_code, get_product_by_vendor_code,
     set_regular_price, set_current_sale_price)
 from rattail.db.api.settings import get_setting, save_setting
 from rattail.db.api.org import get_department, get_subdepartment
 from rattail.db.api.stores import get_store
 from rattail.db.api.vendors import get_vendor
+
+from .users import make_username
