@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2018 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -32,8 +32,8 @@ from sqlalchemy.ext.declarative import declared_attr
 from sqlalchemy.ext.associationproxy import association_proxy
 from sqlalchemy.ext.orderinglist import ordering_list
 
-from rattail.db.model import Base, LabelProfile, BatchMixin, ProductBatchRowMixin, uuid_column, getset_factory
-from rattail.db.model.batch import filename_column
+from rattail.db.model import Base, LabelProfile, BatchMixin, ProductBatchRowMixin, getset_factory
+from rattail.db.core import uuid_column, filename_column
 
 
 class LabelBatch(BatchMixin, Base):
@@ -50,6 +50,8 @@ class LabelBatch(BatchMixin, Base):
         return cls.__default_table_args__() + (
             sa.ForeignKeyConstraint(['handheld_batch_uuid'], ['batch_handheld.uuid'],
                                     name='label_batch_fk_handheld_batch'),
+            sa.ForeignKeyConstraint(['label_profile_uuid'], ['label_profile.uuid'],
+                                    name='label_batch_fk_label_profile'),
         )
 
     handheld_batch_uuid = sa.Column(sa.String(length=32), nullable=True)
@@ -68,6 +70,25 @@ class LabelBatch(BatchMixin, Base):
 
     filename = filename_column()
 
+    static_prices = sa.Column(sa.Boolean(), nullable=True, default=False, doc="""
+    Flag indicating whether product prices within the batch should be
+    considered "static" or if they should be updated during batch refresh,
+    i.e. read from current product record.
+    """)
+
+    label_code = sa.Column(sa.String(length=30), nullable=True, doc="""
+    Code (string) of the label type (profile) which should be used when
+    printing the rows.  Note that each row may override this.
+    """)
+
+    label_profile_uuid = sa.Column(sa.String(length=32), nullable=True)
+    label_profile = orm.relationship(
+        LabelProfile,
+        doc="""
+        Reference to the label "profile" which contains details of how the
+        rows should be printed.  Note that each row may override this.
+        """)
+
 
 class LabelBatchFromHandheld(Base):
     """
@@ -151,7 +172,7 @@ class LabelBatchRow(ProductBatchRowMixin, Base):
     # label fields
     ####################
 
-    label_code = sa.Column(sa.String(length=3), nullable=True, doc="""
+    label_code = sa.Column(sa.String(length=30), nullable=True, doc="""
     Code (string) of the label type (profile) which should be used when
     printing this row/product.
     """)
