@@ -212,6 +212,11 @@ class Product(Base):
     Whether or not the product must be weighed to determine its final price.
     """)
 
+    average_weight = sa.Column(sa.Numeric(precision=12, scale=3), nullable=True, doc="""
+    Average weight of a single item "unit", e.g. the weight of one single apple.
+    Useful for estimating final weight for when a customer orders 3 apples, etc.
+    """)
+
     unit_uuid = sa.Column(sa.String(length=32), nullable=True)
 
     unit = orm.relationship(
