@@ -72,6 +72,15 @@ BATCH_ACTION = {
     }
 
 
+CUSTORDER_BATCH_MODE_CREATING            = 10
+CUSTORDER_BATCH_MODE_GATHERING           = 20
+
+CUSTORDER_BATCH_MODE = {
+    CUSTORDER_BATCH_MODE_CREATING        : "creating",
+    CUSTORDER_BATCH_MODE_GATHERING       : "gathering",
+}
+
+
 EMAIL_ATTEMPT_CREATED           = 0
 EMAIL_ATTEMPT_SUCCESS           = 1
 EMAIL_ATTEMPT_FAILURE           = 2
