@@ -282,6 +282,7 @@ class Email(object):
     abstract = False
     default_prefix = "[rattail]"
     default_subject = "Automated message"
+    universal_subject = "Automated message"
 
     # Whether or not the email's :attr:`to` attribute is dynamically determined
     # at run-time, i.e. via some logic other than typical reading from config.
@@ -395,6 +396,27 @@ class Email(object):
             prefix = "[STAGE] {}".format(prefix)
         return prefix
 
+    def get_default_subject(self):
+        return self.default_subject
+
+    def get_subject_template(self):
+        """
+        Returns the template to be used to build the subject.
+        """
+        # use explicitly configured subject if there is one
+        template = self.config.get('rattail.mail', '{}.subject'.format(self.key))
+        if template:
+            return template
+
+        # or if this email defines a custom default, use that
+        default = self.get_default_subject()
+        if default != self.universal_subject:
+            return default
+
+        # otherwise fall back to the global configured default
+        return self.config.get('rattail.mail', 'default.subject',
+                               default=self.universal_subject)
+
     def get_subject(self, data={}, render=True, template=UNSPECIFIED):
         """
         Returns the base value for the message's subject header, i.e. minus
@@ -403,10 +425,7 @@ class Email(object):
         :rtype: str
         """
         if template is UNSPECIFIED:
-            template = self.config.get('rattail.mail', '{}.subject'.format(self.key),
-                                       default=self.default_subject)
-            if not template:
-                template = self.config.get('rattail.mail', 'default.subject')
+            template = self.get_subject_template()
         if template and render:
             return Template(template).render(**data)
         return template
